aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorRafael Garcia-Suarez <rgarciasuarez@mandriva.org>2005-10-28 14:10:21 +0000
committerRafael Garcia-Suarez <rgarciasuarez@mandriva.org>2005-10-28 14:10:21 +0000
commit8361717ed079f031eccf4e9713997b40d7a8035f (patch)
treef040faafffa0a2b3768ed726815cdd0693273282
parent7a69f127cbc89d5f5cfa3ddc30221695fdf85db6 (diff)
downloadperl-URPM-8361717ed079f031eccf4e9713997b40d7a8035f.tar
perl-URPM-8361717ed079f031eccf4e9713997b40d7a8035f.tar.gz
perl-URPM-8361717ed079f031eccf4e9713997b40d7a8035f.tar.bz2
perl-URPM-8361717ed079f031eccf4e9713997b40d7a8035f.tar.xz
perl-URPM-8361717ed079f031eccf4e9713997b40d7a8035f.zip
Use new MDV namespace
-rw-r--r--URPM/Build.pm6
-rw-r--r--t/parse.t10
2 files changed, 4 insertions, 12 deletions
diff --git a/t/parse.t b/t/parse.t
index ace8553..9bcc24c 100644
--- a/t/parse.t
+++ b/t/parse.t
@@ -4,16 +4,8 @@
use strict;
use warnings;
-
-BEGIN {
- eval { require Packdrakeng };
- if ($@) {
- print "1..0 # SKIP: no Packdrakeng here\n";
- exit 0;
- }
-}
-
use Test::More tests => 24;
+use MDV::Packdrakeng;
use URPM;
use URPM::Build;
use URPM::Query;
diff --git a/URPM/Build.pm b/URPM/Build.pm
index 6debbc0..ec421f0 100644
--- a/URPM/Build.pm
+++ b/URPM/Build.pm
@@ -399,7 +399,7 @@ sub compute_deps {
#- end : index of last package (defaults to last index of depslist).
#- idlist : id list of rpm to compute (defaults is start .. end)
#- ratio : compression ratio (default 4).
#- split : split ratio (default 400kb, see Packdrakeng).
sub build_hdlist {
my ($urpm, %options) = @_;
my ($dir, $ratio, @idlist);
@@ -419,8 +419,8 @@ sub build_hdlist {
#- 3 7.6 sec 8.60Mb
$ratio = $options{ratio} || 4;
- require Packdrakeng;
- my $pack = Packdrakeng->new(
+ require MDV::Packdrakeng;
+ my $pack = MDV::Packdrakeng->new(
archive => $options{hdlist},
compress => "gzip",
uncompress => "gzip -d",
@@ -399,7 +399,7 @@ sub compute_deps {
#- idlist : id list of rpm to compute (defaults is start .. end)
#- ratio : compression ratio (default 4).
-#- split : split ratio (default 400kb, see Packdrakeng).
+#- split : split ratio (default 400kb, see MDV::Packdrakeng).
sub build_hdlist {
my ($urpm, %options) = @_;